SystemOrganization addCategory: #'Volunteer-Marketplace'!

Object subclass: #Coordinator2
	instanceVariableNames: 'name email organization coordinatedProjects coordinatorCollection'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Volunteer-Marketplace'!

!Coordinator2 commentStamp: '<historical>' prior: 0!
stores a coordinator!

!Coordinator2 methodsFor: 'accessing' stamp: 'BBC 10/1/2012 10:55'!
coordinatedProjects: aString
	"to set the value of coordinatedProjects"
	coordinatedProjects add: aString.
	coordinatorCollection at: #coordinatedProjects put: coordinatedProjects.

! !

!Coordinator2 methodsFor: 'create/remove/edit' stamp: 'BBC 10/1/2012 10:55'!
createProject: projectName
	"creates a new Project"

	| aProject|
	
	"Project Aspects"
	aProject := VolunteerProject new.
	aProject name: projectName.
	aProject coordinators: name.
	
	"Coordinator Aspects"
	(coordinatedProjects = nil) 
		ifTrue: [coordinatedProjects := Set with: projectName]
		ifFalse: [coordinatedProjects add: projectName].
			
	"Persistence"
	aProject save.
	

	
	! !

!Coordinator2 methodsFor: 'create/remove/edit' stamp: 'BBC 10/1/2012 10:55'!
deleteProject: aProject
	"to delete a project"

	| fileName fileOps|
	
	fileName := '/Users/bruno/Desktop/Volunteers/', aProject, '.txt'.
	fileOps := FileDirectory new. 
	fileOps deleteFileNamed: fileName.
	Transcript cr; show: fileName, ' removed.'

	
	

	

	
	! !

!Coordinator2 methodsFor: 'accessing' stamp: 'BBC 10/1/2012 10:55'!
email: aString
	"to set the value of email"
	email := aString.
	coordinatorCollection at: #email put: aString.! !

!Coordinator2 methodsFor: 'initialize-release' stamp: 'BBC 10/1/2012 10:55'!
initialize
	"Creates a collection to handle coordinator aspects"
	
	coordinatedProjects := Set new.
	coordinatorCollection := Dictionary newFrom: {#name->nil. #email->nil. 												                                                                              #organization->nil.#coordinatedProjects->coordinatedProjects}.
	
! !

!Coordinator2 methodsFor: 'accessing' stamp: 'BBC 10/1/2012 10:55'!
name: aString
	"to set the value of name"
	name := aString.
	coordinatorCollection at: #name put: aString.! !

!Coordinator2 methodsFor: 'accessing' stamp: 'BBC 10/1/2012 10:55'!
organization: aString
	"to set the value of organization"
	organization := aString.
	coordinatorCollection at: #organization put: aString.! !

!Coordinator2 methodsFor: 'create/remove/edit' stamp: 'BBC 10/1/2012 10:55'!
readProject: aProject
	"to read project args"

	| fileName fileStream line |
	
	fileName := '/Users/bruno/Desktop/Volunteers/', aProject, '.txt'.
	fileStream := FileStream fileNamed: fileName.
	[fileStream atEnd] whileFalse: [line := fileStream nextLine. Transcript cr; show: (line)].
	
	

	

	
	! !

!Coordinator2 methodsFor: 'persistence' stamp: 'BBC 10/1/2012 10:55'!
save
	"to write coordinator into a file"

	| fileName fileStream |
	
	fileName := '/Users/bruno/Desktop/Volunteers/', name, '.txt'.
	fileStream := FileStream forceNewFileNamed: fileName.
	fileStream nextPutAll: 'Name: ', (coordinatorCollection at: #name) printString; cr.
	fileStream nextPutAll: 'Email: ', (coordinatorCollection at: #email) printString; cr.
	fileStream nextPutAll: 'Organization: ', (coordinatorCollection at: #organization) printString; cr.
	fileStream nextPutAll: 'Coordinated Projects: '.
	coordinatedProjects do: [:value | fileStream nextPutAll: value printString].
	fileStream close.
	Transcript cr; show: fileName, ' saved.'! !

Object subclass: #Skill
	instanceVariableNames: 'name description'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Volunteer-Marketplace'!

!Skill commentStamp: 'RG 9/19/2012 20:57' prior: 0!
Represent a skill of a volunteer or needed in a task.!

!Skill methodsFor: 'comparing' stamp: 'RG 9/19/2012 22:00'!
= aSkill
	"Testing Equality"
	^ (self name) = (aSkill name).! !

!Skill methodsFor: 'accessors' stamp: 'RG 9/19/2012 21:00'!
description
	"Getter of description"
	^description.! !

!Skill methodsFor: 'accessors' stamp: 'RG 9/19/2012 21:01'!
description: aDescription
	"Setter of description"
	description := aDescription.! !

!Skill methodsFor: 'initialize-release' stamp: 'RG 9/19/2012 21:04'!
initialize
	"Empty constructor"
	super initialize.
	self name: ''.
	self description: ''.! !

!Skill methodsFor: 'initialize-release' stamp: 'RG 9/19/2012 21:06'!
initialize: aName desc: aDescription
	"Constructor with parameters"
	self name: aName.
	self description: aDescription.! !

!Skill methodsFor: 'accessors' stamp: 'RG 9/19/2012 20:58'!
name
	"Getter of a name"
	^name.! !

!Skill methodsFor: 'accessors' stamp: 'RG 9/19/2012 20:59'!
name: aName
	"Setter of name"
	name := aName.! !

Object subclass: #Task
	instanceVariableNames: 'name skills volunteers description state estimatedTime startDate endDate'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Volunteer-Marketplace'!

!Task commentStamp: 'RG 9/19/2012 22:28' prior: 0!
Represents a project task.!

!Task methodsFor: 'as yet unclassified' stamp: 'RG 9/19/2012 22:38'!
addSkill: aSkill
	"Add a needed skill to the task"
	[ self hasSkill: aSkill ] ifFalse: [ skills add: aSkill. ].! !

!Task methodsFor: 'as yet unclassified' stamp: 'RG 9/19/2012 22:39'!
addVolunteer: aVolunteer
	"Adds a volunteer to perform the task"
	volunteers add: aVolunteer.! !

!Task methodsFor: 'as yet unclassified' stamp: 'RG 9/19/2012 22:37'!
hasSkill: aSkill
	"Test if contains a skill"
	^ skills includes: aSkill.! !

!Task methodsFor: 'initialize-release' stamp: 'RG 9/19/2012 22:34'!
initialize
	"Constructor"
	skills := OrderedCollection new.
	volunteers := OrderedCollection new.
	startDate := Date new.
	endDate := Date new.
	description := ''.
	name := ''.
	state := ''.
	estimatedTime := 0.! !

Object subclass: #Volunteer
	instanceVariableNames: 'skills disponibility availability workTime finishedTasks finishedProjects birthday'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Volunteer-Marketplace'!

!Volunteer commentStamp: 'RG 9/19/2012 21:15' prior: 0!
Represents a volunteer.!

!Volunteer methodsFor: 'as yet unclassified' stamp: 'RG 9/19/2012 21:30'!
addSkill: aSkill
	"Add a skill to the volunteer"
	skills add: aSkill.! !

!Volunteer methodsFor: 'accessors' stamp: 'RG 9/19/2012 21:41'!
availability
	"Getter availability"
	^availability.! !

!Volunteer methodsFor: 'accessors' stamp: 'RG 9/19/2012 21:43'!
availability: anAvailability
	"Setter of availability"
	availability := anAvailability.! !

!Volunteer methodsFor: 'accessors' stamp: 'RG 9/19/2012 21:37'!
birthday
	"Getter of birthday"
	^birthday.! !

!Volunteer methodsFor: 'accessors' stamp: 'RG 9/19/2012 21:38'!
birthday: aBirthday
	"Setter of Birthday"
	birthday := aBirthday.! !

!Volunteer methodsFor: 'accessors' stamp: 'RG 9/19/2012 21:39'!
disponibility
	"Getter of disponibility"
	^disponibility.! !

!Volunteer methodsFor: 'accessors' stamp: 'RG 9/19/2012 21:41'!
disponibility: aDisponibility
	"Setter of disponibility"
	disponibility := aDisponibility.! !

!Volunteer methodsFor: 'accessors' stamp: 'RG 9/19/2012 21:46'!
finishedProjects
	"Getter finishedProjects"
	^finishedProjects.! !

!Volunteer methodsFor: 'accessors' stamp: 'RG 9/19/2012 21:47'!
finishedProjects: numberFinished
	"Setter finishedPrijects"
	finishedProjects := numberFinished.! !

!Volunteer methodsFor: 'accessors' stamp: 'RG 9/19/2012 21:49'!
finishedTasks
	"Getter finishedTasks"
.	^finishedTasks.! !

!Volunteer methodsFor: 'accessors' stamp: 'RG 9/19/2012 21:49'!
finishedTasks: numberFinished
	"Setter finished Tasks"
	finishedTasks := numberFinished.! !

!Volunteer methodsFor: 'as yet unclassified' stamp: 'RG 9/19/2012 22:07'!
hasSkill: aSkill
	"Test if has an specific skill"
	^ skills includes: aSkill.! !

!Volunteer methodsFor: 'initialize-release' stamp: 'RG 9/19/2012 22:06'!
initialize
	"Constructor"
	skills := OrderedCollection new.
	disponibility := ''.
	availability := false.
	workTime := ''.
	finishedTasks := 0.
	finishedProjects := 0.
	birthday := Date new.
	! !

!Volunteer methodsFor: 'accessors' stamp: 'RG 9/19/2012 21:44'!
workTime
	"Getter of worktime"
	^workTime.! !

!Volunteer methodsFor: 'accessors' stamp: 'RG 9/19/2012 21:45'!
workTime: aWorkTime
	"comment stating purpose of message"
	workTime := aWorkTime.! !
